using System;
using System.Collections.Generic;
using Infragistics;
using MonoTouch.Foundation;
using MonoTouch.ObjCRuntime;

namespace StackedDynamic_CS
{
	public class DynamicStackedDataSource : IGStackedSeriesDataSource
	{
		//This structure is the array of custom objects, from which the fragments will be extracted.
		[Export("Data")]
		NSObject[] Data { get; set; }

		//Determines the property name of the items in the data array to be used for labels.
		[Export("LabelPath")]
		string LabelPath { get; set; }

		//Determines the property name of the items in the data array to be used for stack values.
		[Export("ValuesPath")]
		string ValuesPath { get; set; }

		public DynamicStackedDataSource ()
		{
		}

		public DynamicStackedDataSource(NSObject[] data, string labelPath, string valuesPath)
		{
			Data = data;
			LabelPath = labelPath;
			ValuesPath = valuesPath;
		}

		public override int NumberOfFragments (IGStackedSeriesBase series)
		{
			if (Data.Length == 0)
				return 0;

			DataModel dataItem = Data [0] as DataModel;
			return (int)dataItem.Points.Count;
		}

		public override int NumberOfPointsInFragment (IGStackedFragmentSeries fragment, IGStackedSeriesBase series)
		{
			return Data.Length;
		}

		public override IGStackedFragmentSeries GetFragment (IGStackedSeriesBase series, int index)
		{
			IGStackedFragmentSeries fragment = new IGStackedFragmentSeries ();
			fragment.Name = index.ToString();
			fragment.Title = index.ToString();
			fragment.ValueProperty = index.ToString();
			return fragment;
		}

		public override IGCategoryPoint GetPoint (IGStackedSeriesBase series, int index, IGStackedFragmentSeries fragment)
		{
			NSString label; 
			DataModel item = (DataModel)Data [index];
			Selector selector = new Selector(LabelPath);

			if (item != null  && NSObject.FromObject(item).RespondsToSelector(selector))
			{
				string labelString = NSObject.FromObject (item).ValueForKey (new NSString (LabelPath)).ToString();
				label = new NSString(labelString);
			}
			else
			{
				label = new NSString(String.Format("Item {0}", index));
			}

			double value = new NSNumber (item.Points.ValueAt (Convert.ToUInt16(fragment.ValueProperty))).DoubleValue;
			IGCategoryPoint point = new IGCategoryPoint (value, label);
			return point;
		}

		public override IGCategoryPoint UpdatePointAtIndex (IGStackedSeriesBase series, int index, IGStackedFragmentSeries fragment)
		{
			IGCategoryPoint newPoint = GetPoint (series, index, fragment);

			NSObject sourceItem = new NSObject (series.DataPoints.ValueAt ((uint)index));

			if (sourceItem != null && sourceItem.GetType() == typeof(NSDictionary))        
			{
				NSNumber value = new NSNumber(newPoint.Value);
				string label = newPoint.Label;

				sourceItem.SetValueForKey (value, new NSString(fragment.ValueProperty));
				sourceItem.SetValueForKey (new NSString(label), new NSString("label"));
			}

			return newPoint;
		}
	}
}

