using System;
using System.Collections.Generic;
using System.Drawing;
using Infragistics;
using MonoTouch.Foundation;
using MonoTouch.ObjCRuntime;
using MonoTouch.UIKit;

namespace StackedDynamic_CS
{
	public class DataModel : NSObject
	{
		[Export("Name")]
		public string Name { get; set; }
		[Export("Title")]
		public string Title { get; set; }
		[Export("Points")]
		public NSMutableArray Points { get; set; }

		public DataModel()
		{
			Points = new NSMutableArray();
		}
	}
	
	public partial class StackedDynamic_CSViewController : UIViewController
	{
		Random _random = new Random (DateTime.Now.Millisecond);
		IGChartView _chartView;
		DynamicStackedDataSource _dataSource;
		List<NSObject> _data;

		public StackedDynamic_CSViewController ()
		{
			_data = new List<NSObject> ();
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			CreateData ();
			_dataSource = new DynamicStackedDataSource (_data.ToArray(), "Name", "Points");

			RectangleF bounds = new RectangleF(0, 0, this.View.Frame.Size.Width, this.View.Frame.Size.Height);
			_chartView = new IGChartView(bounds);
			_chartView.AutoresizingMask = UIViewAutoresizing.FlexibleHeight | UIViewAutoresizing.FlexibleWidth;
			_chartView.BackgroundColor = UIColor.White;
			_chartView.Theme = IGChartDefaultThemes.IGTheme();
			_chartView.AddStackedSeries(new Class(typeof(IGStacked100ColumnSeries)), "series", _dataSource, "xAxis", "yAxis");
			(this.View).AddSubview(_chartView);
		}

		void CreateData()
		{
			int totalPoints = _random.Next(10) + 2;
			int totalFragments = _random.Next(5) + 2;

			for (int i = 0; i < totalFragments; i++) 
			{
				DataModel dataModel = new DataModel ();
				dataModel.Name = String.Format ("Fragment {0}", i);
				dataModel.Title = String.Format ("Title {0}", i);

				for (int j = 0; j < totalPoints; j++) 
				{
					dataModel.Points.Add (new NSNumber(_random.Next (100)));
				}
				_data.Add (dataModel);
			}
		}
	}
}

