//
// Created by TBetts on 11/12/13.
//


#import "DynamicStackedDataSource.h"
#import "igViewController.h"


@implementation DynamicStackedDataSource

- (id)initWithData:(NSArray *)data labelPath:(NSString *)labelPath valuesPath:(NSString *)valuesPath
{
    self = [super init];
    if (self)
    {
        self.data = data;
        self.labelPath = labelPath;
        self.valuesPath = valuesPath;
    }

    return self;
}

+ (id)sourceWithData:(NSArray *)data labelPath:(NSString *)labelPath valuesPath:(NSString *)valuesPath
{
    return [[self alloc] initWithData:data labelPath:labelPath valuesPath:valuesPath];
}

- (int)numberOfFragmentsInSeries:(IGStackedSeriesBase *)series
{
    if (_data.count == 0)
        return 0;

    DataModel *dataItem = (DataModel *)[_data objectAtIndex:0];
    return (int)dataItem.points.count;
}

- (int)numberOfPointsInFragment:(IGStackedFragmentSeries *)fragment forSeries:(IGStackedSeriesBase *)series
{
    return _data.count;
}

- (IGStackedFragmentSeries *)series:(IGStackedSeriesBase *)series fragmentAtIndex:(int)index
{
    IGStackedFragmentSeries *fragment = [[IGStackedFragmentSeries alloc] init];
    NSString *indexString = [NSString stringWithFormat:@"%d", index];
    fragment.Name = indexString;
    fragment.Title = indexString;
    fragment.ValueProperty = indexString;
    return fragment;
}

- (IGCategoryPoint *)series:(IGStackedSeriesBase *)series pointAtIndex:(int)index forFragment:(IGStackedFragmentSeries *)fragment
{
    NSString *label;
    DataModel *item = (DataModel *)[_data objectAtIndex:index];
    label = (NSString *)[item valueForKey:_labelPath];

    if (item == nil  && label == nil)
    {
        label = [NSString stringWithFormat:@"Item %d", index];
    }

    NSInteger valueIndex = [fragment.valueProperty integerValue];
    NSArray *valueArray = (NSArray *)[item valueForKey:_valuesPath];
    double value = ((NSNumber *)[valueArray objectAtIndex:valueIndex]).doubleValue;
    IGCategoryPoint *point = [[IGCategoryPoint alloc] initWithValue:value andLabel:label];
    return point;
}

- (IGCategoryPoint *)series:(IGStackedSeriesBase *)series updatePointAtIndex:(int)index forFragment:(IGStackedFragmentSeries *)fragment
{
    IGCategoryPoint *newPoint = [self series:series pointAtIndex:index forFragment:fragment];

    NSDictionary *sourceItem = (NSDictionary *)[series.dataPoints objectAtIndex:index];

    if (sourceItem != nil)
    {
        NSNumber *value = [NSNumber numberWithDouble:newPoint.value];
        NSString *label = newPoint.label;

        [sourceItem setValue:value forKey:fragment.valueProperty];
        [sourceItem setValue:label forKey:@"label"];
    }

    return newPoint;
}

@end